==> apache-nuttx-apps-12.7.0.tar.gz: apps/testing/testsuites/kernel/sched/common/test_sched_common.c <==
/****************************************************************************
 * apps/testing/testsuites/kernel/sched/common/test_sched_common.c
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>
#include <stdio.h>
#include <stdint.h>
#include <stdarg.h>
#include <stddef.h>
#include <setjmp.h>
#include <cmocka.h>
#include <syslog.h>
#include "SchedTest.h"

/****************************************************************************
 * Public Functions
 ****************************************************************************/

/****************************************************************************
 * Name: test_nuttx_schedtest_group_setup
 ****************************************************************************/

int test_nuttx_schedtest_group_setup(void **state)
{
  /* syslog(LOG_INFO, "This is goup setup !\n"); */

  return 0;
}

/****************************************************************************
 * Name: test_nuttx_schedtest_group_teardown
 ****************************************************************************/

int test_nuttx_schedtest_group_teardown(void **state)
{
  /* syslog(LOG_INFO, "This is goup tearDown !\n"); */

  return 0;
}

==> apache-nuttx-apps-12.11.0.tar.gz: apps/testing/testsuites/kernel/sched/common/test_sched_common.c <==
/****************************************************************************
 * apps/testing/testsuites/kernel/sched/common/test_sched_common.c
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/
#include <nuttx/config.h>
#include <stdio.h>
#include <stdint.h>
#include <stdarg.h>
#include <stddef.h>
#include <setjmp.h>
#include <cmocka.h>
#include <syslog.h>
#include "SchedTest.h"

/****************************************************************************
 * Public Functions
 ****************************************************************************/

/****************************************************************************
 * Name: test_nuttx_sched_test_group_setup
 ****************************************************************************/

int test_nuttx_sched_test_group_setup(void **state)
{
  /* syslog(LOG_INFO, "This is goup setup !\n"); */

  return 0;
}

/****************************************************************************
 * Name: test_nuttx_sched_test_group_teardown
 ****************************************************************************/

int test_nuttx_sched_test_group_teardown(void **state)
{
  /* syslog(LOG_INFO, "This is goup tearDown !\n"); */

  return 0;
}
